def find_diffrent_key_from_str(date1,date2):
    # 调用此函数可以快速对比两列字符串，查找出key值不一样的值，用于在数据爬取过程中快速对比并查找出需要破解的参数
    def change_txt_to_list(info_list):
        info_list=info_list.split('&')
        result={}
        for i in range(len(info_list)):
            info=info_list[i].split('=')
            result[info[0]]=info[1]
        return  result
    date1=change_txt_to_list(date1)
    date2=change_txt_to_list(date2)
    for son in date2.keys():
        if date1[son]!=date2[son]:
            print(son+':\n  (1)'+date1[son]+'\n  (2)'+date2[son])


import json
def SelecTHead(html,dict):
    text_single = '''<div data-v-6e2a8889="" style="display: inline-block;position: relative;cursor: pointer;height: 3%;line-height: 23px;border: 1px solid #000000;color: #000000;background: #b8c0e0;padding: 0 8px;font-size: 12px;margin-left: 5px;margin-top: 4px" onclick="window.open('显示地址','_self')">显示名称<!----></div>'''
    text_sum = text_single.replace('显示名称', dict[0]['名称']).replace('显示地址', dict[0]['地址'])
    for i in range(1,len(dict)):
        text_single='''<div data-v-6e2a8889="" style="display: inline-block;position: relative;cursor: pointer;height: 3%;line-height: 23px;border: 1px solid #000000;color: #000000;background: #b8c0e0;padding: 0 8px;font-size: 12px;margin-left: 5px;margin-top: 4px" onclick="window.open('显示地址','_self')">显示名称<!----></div>'''
        text_sum=text_sum+text_single.replace('显示名称',dict[i]['名称']).replace('显示地址',dict[i]['地址'])
    text_sum='''<body style="background-color: #000649;">
    <style>.box {  } </style>        <!--=========================================-->
    <div class="box" style="background-color: #000649;width: 100%;height:100%">
        <!--=========================================-->
<div ">'''+text_sum+'''</div>
</div>
<!--=========================================-->'''
    with open(html, "r", encoding="utf8") as f:
        f=f.read()
    f=f.replace('''<body >
    <style>.box {  } </style>    <div class="box">''',text_sum)
    with open(html,'w',encoding='utf-8') as ff:
        ff=ff.write(f)
    return text_sum
def px_to_percent(path,width,height):
    # px_to_percent('F:\系统\桌面\chart_config.json', 923, 570)
    with open(path,encoding='utf-8') as f:
        f=f.read()
        f=json.loads(f)
    def get_int(date,sum):
        date=str(int(float(date[:-2])/sum*1000)/10)+'%'
        return date
    for i in range(len(f)):
        f[i]['width']=get_int(f[i]['width'],width)
        f[i]['left']=get_int(f[i]['left'],width)
        f[i]['height']=get_int(f[i]['height'],height)
        f[i]['top']=str(float(get_int(f[i]['top'],height)[:-1]))+'%'
    f=json.dumps(f)
    with open(path,'w',encoding='utf-8') as ff:
        ff.write(f)


from KwoksTool.info import (welcome,how)
from KwoksTool.function import (GetCityNumFromLiepin,
                                GetCityNumFromBossZhiPing,
                                GetCityNameFromLiepin,
                                YesOrNot,
                                CheckIp,
                                IntoZip,
                                ZipOut,
                                SendEmail,
                                GetEmail,
                                ProgressBar,
                                MergeTable,
                                ChoiceColumn)
from KwoksTool.source.IpPool import GetIpPool
from KwoksTool.model import (GetProbMatrix,ToMat)
from KwoksTool.spider import (Browser, PlateComponentStocks)
from KwoksTool.Spider.stock import GetStocksData
class spider:
    from KwoksTool.Spider.function import (find_diffrent_key_from_str)
    from KwoksTool.source.IpPool import (get_ip_from_shop)
class show:
    from KwoksTool.Show.function import (SelecTHead,px_to_percent)
class function:
    from KwoksTool.function import (PackageWithoutBorderBorder,Package,DeleteAll,PackageService)
dependencies=[
    'altgraph==0.17.3',
    'attrs==23.1.0',
    'beautifulsoup4==4.12.2',
    'bleach==6.0.0',
    'blinker==1.6.2',
    'bs4==0.0.1',
    'build==0.10.0',
    'certifi==2023.7.22',
    'cffi==1.15.1',
    'charset-normalizer==3.2.0',
    'click==8.1.6',
    'colorama==0.4.6',
    'docutils==0.20.1',
    'et-xmlfile==1.1.0',
    'exceptiongroup==1.1.2',
    'Flask==2.3.2',
    'h11==0.14.0',
    'idna==3.4',
    'importlib-metadata==6.8.0',
    'itsdangerous==2.1.2',
    'jaraco.classes==3.3.0',
    'Jinja2==3.1.2',
    'keyring==24.2.0',
    'lxml==4.9.3',
    'markdown-it-py==3.0.0',
    'MarkupSafe==2.1.3',
    'mdurl==0.1.2',
    'more-itertools==10.1.0',
    'numpy==1.25.2',
    'openpyxl==3.1.2',
    'outcome==1.2.0',
    'packaging==23.1',
    'pandas==2.0.3',
    'pefile==2023.2.7',
    'pkginfo==1.9.6',
    'prettytable==3.8.0',
    'pycparser==2.21',
    'pyecharts==2.0.3',
    'PyExecJS==1.5.1',
    'Pygments==2.16.1',
    'pyinstaller==5.13.0',
    'pyinstaller-hooks-contrib==2023.6',
    'pyproject_hooks==1.0.0',
    'PySocks==1.7.1',
    'python-dateutil==2.8.2',
    'pytz==2023.3',
    'pywin32-ctypes==0.2.2',
    'readme-renderer==40.0',
    'requests==2.31.0',
    'requests-toolbelt==1.0.0',
    'rfc3986==2.0.0',
    'rich==13.5.2',
    'selenium==4.9.0',
    'simplejson==3.19.1',
    'six==1.16.0',
    'sniffio==1.3.0',
    'sortedcontainers==2.4.0',
    'soupsieve==2.4.1',
    'tomli==2.0.1',
    'trio==0.22.2',
    'trio-websocket==0.10.3',
    'tushare==1.2.89',
    'twine==4.0.2',
    'tzdata==2023.3',
    'urllib3==1.26.16',
    'wcwidth==0.2.6',
    'webencodings==0.5.1',
    'websocket-client==0.57.0',
    'Werkzeug==2.3.6',
    'wsproto==1.2.0',
    'zipp==3.16.2',
    'xlrd==2.0.1',
    'matplotlib==3.7.2'
]